pycocoa.octypes.SEL_t

Package pycocoa :: Module octypes :: Class SEL_t |
[frames] | no frames]

# Class SEL_t

          object --+
                   |
           ??._CData --+
                       |
    _ctypes._SimpleCData --+
                           |
             ctypes.c_void_p --+
                               |
                          ObjC_t --+
                                   |
                                  SEL_t

ObjC `SELector/cmd` type, encoding `b':'`.

Instance Methods
__repr__(self) repr(x) |
__str__(self) str(x) |
Inherited from `ctypes.c_void_p`: `from_param` Inherited from `_ctypes._SimpleCData`: `__ctypes_from_outparam__`, `__init__`, `__new__`, `__nonzero__` Inherited from `_CData`: `__hash__`, `__reduce__`, `__setstate__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| name_ N/A
Inherited from `ObjC_t`: `typename` Inherited from `_ctypes._SimpleCData`: `value` Inherited from `object`: `__class__`

Method Details

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)

### __str__(self) (Informal representation operator) |
str(x) Overrides: object.__str__ (inherited documentation)

Property Details

### name_ N/A Get Method: name_(self) Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.